@@ -158,7 +158,8 @@ def extract_BM(timeseries, block_size=10, stride='DBM', return_indices=False):
     :param block_size: int, optional
         The size of each block for extracting maxima. Default is 10.
     :param stride: str or int, optional
-        The stride used to move the window. Can be 'DBM' (Disjoint Block Maxima)
+        The stride used to move the window. Can be 'DBM' (Disjoint Block Maxima), 
+        'SBM' (Sliding Block Maxima), 'ABM' (All Block Maxima),
         or an integer specifying the stride size. Default is 'DBM'.
 
     Returns
@@ -234,12 +235,15 @@ def extract_HOS(timeseries, orderstats=2, block_size=10, stride='DBM'):
     if stride == 'DBM' or stride == 'SBM':
         p = misc.stride2int(stride, block_size)
         out = [np.sort(timeseries[i*p:i*p+r])[-orderstats:] for i in range((n-r)//p+1)]
+        return np.array(out)
     elif stride == 'ABM':
         timeseries_srtd = np.sort(timeseries)[::-1]
         out = [timeseries_srtd[i] for i in range(n-r+1)]
+        out = np.array(out).reshape(-1,1)
+        return out
     else:
         raise ValueError('Stride must be one of "DBM", "SBM", or "ABM"')
-    return np.array(out).reshape(-1,1)
+    return 
     
 
 def automatic_parameter_initialization(PWM_estimators, corr, ts=0.5):
@@ -1043,7 +1047,7 @@ class Frechet_ML_estimators:
         """
         return len(self.values)
 
-    def get_ML_estimation(self, PWM_estimators=None, initParams = 'auto', r=None):
+    def get_ML_estimation(self, PWM_estimators=None, initParams = 'auto', r=None, weights=None):
         r"""
         Compute ML estimators (alpha, sigma) for each high order statistics series using Frechet distribution.
 
@@ -1086,7 +1090,7 @@ class Frechet_ML_estimators:
                 cst = - Frechet_log_likelihood(ho_stat, alpha=alpha, sigma=sigma, r=r, weights=weights)
                 return cst
             
-            inits = [1/initParams[i][0], initParams[i][2]]
+            inits = [np.max([1/initParams[i][0], 0.001]), np.max([initParams[i][2], 0.001])]
             #its = initParams[i][::2]
             results = misc.minimize(cost, inits, method='Nelder-Mead', bounds=((1e-6, np.inf),(1e-5, np.inf)))
             # results = misc.minimize(cost, inits, method='COBYLA', bounds=((0, np.inf),(0, np.inf)))
@@ -1450,9 +1454,16 @@ class TimeSeries:
             hos = extract_HOS(series, orderstats=orderstats, block_size=block_size, stride=stride)
             self.high_order_stats.append(hos)
     
-    def get_ABM_weights(self):
+    def get_ABM_weights(self, recursively=True):
         r""""Computes weights for MLE with ABM stride"""
-        return [comb(self.len-i-1, self.block_size-1, exact=False) for i in range(self.len-self.block_size+1)]
+        if recursively:
+            abm_weights = [self.block_size/self.len]
+            for i in range(self.len-self.block_size):
+                abm_weights.append(abm_weights[-1]*(self.len-self.block_size-i-1)/(self.len-2-i))
+            return abm_weights
+        else:
+            print('caution: using binominal coeffs')
+            return [comb(self.len-i-1, self.block_size-1, exact=False) for i in range(self.len-self.block_size+1)]
     
     def plot(self, rep=1, filename=None):
         r"""
